# The Npz loader and saver

The Npz loader and saver comes also with an extended interface providing a `dtype` parameter
for setting the format of the output `i` and `q` values accordingly for loading and saving.